@@ -10,6 +10,8 @@ context("pin")
 
 test_that("We can access a URL with an unverified pin", {
 
+  skip_if_offline()
+  skip_on_cran()
   
   path <- pin(url, verify = FALSE)
   
@@ -26,6 +28,8 @@ test_that("We can access a URL with an unverified pin", {
 
 test_that("We can access a URL with pin", {
   
+  skip_if_offline()
+  skip_on_cran()
   
   path <- pin(url)
    
